@@ -260,6 +260,12 @@ class MoveLine(metaclass=PoolMeta):
         return super()._get_origin() + [
             'account.invoice.line', 'account.invoice.tax']
 
+    @classmethod
+    def copy(cls, lines, default=None):
+        default = {} if default is None else default.copy()
+        default.setdefault('invoice_payments', None)
+        return super().copy(lines, default=default)
+
     @classmethod
     def get_invoice_payment(cls, lines, name):
         pool = Pool()
