@@ -10,15 +10,23 @@ from trytond.tests.test_tryton import doctest_teardown
 from trytond.tests.test_tryton import doctest_checker
 from trytond.pool import Pool
 
+from trytond.modules.company.tests import (
+    PartyCompanyCheckEraseMixin, CompanyTestMixin)
 from trytond.modules.currency.tests import create_currency
 
+from ..exceptions import PaymentTermValidationError
+
 
 def set_invoice_sequences(fiscalyear):
     pool = Pool()
     Sequence = pool.get('ir.sequence.strict')
+    SequenceType = pool.get('ir.sequence.type')
     InvoiceSequence = pool.get('account.fiscalyear.invoice_sequence')
 
-    sequence = Sequence(name=fiscalyear.name, code='account.invoice')
+    sequence_type, = SequenceType.search([
+            ('name', '=', "Invoice"),
+            ], limit=1)
+    sequence = Sequence(name=fiscalyear.name, sequence_type=sequence_type)
     sequence.company = fiscalyear.company
     sequence.save()
     fiscalyear.invoice_sequences = []
@@ -32,7 +40,8 @@ def set_invoice_sequences(fiscalyear):
     return fiscalyear
 
 
-class AccountInvoiceTestCase(ModuleTestCase):
+class AccountInvoiceTestCase(
+        PartyCompanyCheckEraseMixin, CompanyTestMixin, ModuleTestCase):
     'Test AccountInvoice module'
     module = 'account_invoice'
 
@@ -98,6 +107,45 @@ class AccountInvoiceTestCase(ModuleTestCase):
                 (datetime.date(2012, 1, 14), Decimal('396.83')),
                 ])
 
+    @with_transaction()
+    def test_payment_term_with_repeating_decimal(self):
+        "Test payment_term with repeating decimal"
+        pool = Pool()
+        PaymentTerm = pool.get('account.invoice.payment_term')
+
+        PaymentTerm.create([{
+                    'name': "Repeating Decimal",
+                    'lines': [
+                        ('create', [{
+                                    'type': 'percent',
+                                    'divisor': Decimal(3),
+                                    'ratio': Decimal('0.3333333333'),
+                                    }, {
+                                    'type': 'remainder',
+                                    }]),
+                        ],
+                    }])
+
+    @with_transaction()
+    def test_payment_term_with_invalid_ratio_divisor(self):
+        "Test payment_term with invalid ratio and divisor"
+        pool = Pool()
+        PaymentTerm = pool.get('account.invoice.payment_term')
+
+        with self.assertRaises(PaymentTermValidationError):
+            PaymentTerm.create([{
+                        'name': "Invalid ratio and divisor",
+                        'lines': [
+                            ('create', [{
+                                        'type': 'percent',
+                                        'divisor': Decimal(2),
+                                        'ratio': Decimal('0.4'),
+                                        }, {
+                                        'type': 'remainder',
+                                        }]),
+                            ],
+                        }])
+
     @with_transaction()
     def test_payment_term_with_empty_value(self):
         'Test payment_term with empty'
@@ -220,6 +268,29 @@ def suite():
             tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite('scenario_invoice_with_credit.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite(
+            'scenario_invoice_supplier_post_paid.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite('scenario_credit_note.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite(
+            'scenario_invoice_customer_sequential.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite(
+            'scenario_invoice_overpayment.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     suite.addTests(doctest.DocFileSuite(
             'scenario_invoice_alternate_currency.rst',
             tearDown=doctest_teardown, encoding='utf-8',
@@ -230,6 +301,15 @@ def suite():
             tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite(
+            'scenario_invoice_tax_deductible.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite('scenario_invoice_group_line.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     suite.addTests(doctest.DocFileSuite(
             'scenario_renew_fiscalyear.rst',
             tearDown=doctest_teardown, encoding='utf-8',
